@@ -1,5 +1,8 @@
 # -*- mode: python; coding: utf-8 -*-
 
+import time
+import thread
+from functools import partial
 from threading import Lock
 from gevent.threadpool import ThreadPool
 
@@ -11,7 +14,7 @@ class Observable:
         self.observers = []
         self.observers_lock = Lock()
 
-        self.pool = ThreadPool(10)
+        self.pool = ThreadPool(3)
 
     def attach(self, observer, current):
         if observer is None or observer in self.observers:
@@ -36,10 +39,15 @@ class Observable:
         if not method_name:
             method_name = "notify"
 
-        for observer in self.observers[:]:
-            self.pool.spawn(self._notify_observer, *((observer, method_name,) + args))
+#        notifyp = partial(self._notify_observer, method_name=method_name, args=args)
+#        self.pool.map_async(notifyp, self.observers)
 
-    def _notify_observer(self, observer, method_name, *args):
+#        for observer in self.observers[:]:
+#            self.pool.apply_async(self._notify_observer, (observer, method_name, args))
+
+    def _notify_observer(self, observer, method_name, args):
+        print "thread ident", thread.get_ident()
+        time.sleep(4)
         try:
             method = getattr(observer, method_name)
             method(*args)
