@@ -16,6 +16,9 @@ logger.setLevel(logging.DEBUG)
 
 pwd = os.path.abspath(os.path.dirname(settings.__file__))
 
+if not hasattr(settings, "WebRequestHandler"):
+    settings.WebRequestHandler = web.RequestHandler
+
 
 class MultiPathLoader(template.BaseLoader):
     def __init__(self, directories, **kwargs):
@@ -41,7 +44,7 @@ class MultiPathLoader(template.BaseLoader):
 
 
 # dirty hack to get control over errors in tornado
-class ErrorHandler(web.RequestHandler):
+class ErrorHandler(settings.WebRequestHandler):
     def initialize(self, status_code):
         self.set_status(status_code)
 
@@ -88,6 +91,7 @@ class AppServer(object):
 
         self.register_common_static_handler()
         self.register_common_urls()
+        self.register_common_servants()
 
     def app_is_healthy(self, app_name):
         try:
@@ -131,24 +135,32 @@ class AppServer(object):
         for locator, handler_ in urls.urlpatterns.items():
             url = "^/{}/{}".format(name, locator)
 
-            class RequestHandler(web.RequestHandler):
-                handler = handler_
+            if isinstance(handler_, type):
+                RequestHandler = handler_
 
-                def get(self):
-                    context = {
-                        'APP_STATIC_PATH': "/{}/static".format(name)
-                    }
-                    return self.handler(context)
+            else:
+                class RequestHandler(settings.WebRequestHandler):
+                    handler = handler_  # automagically passes 'self'
+                    context = {'APP_STATIC_PATH': "/{}/static".format(name)}
 
-                def create_template_loader(self, path):
-                    app_template_path = os.path.join(path, "templates")
+                    if getattr(handler_, "use_post", None):
+                        def post(self):
+                            return self.handler(self.context)
+                    else:
+                        def get(self):
+                            return self.handler(self.context)
 
-                    all_paths = []
-                    if os.path.exists(app_template_path):
-                        all_paths.append(app_template_path)
+            def create_template_loader(self, path):
+                app_template_path = os.path.join(path, "templates")
 
-                    all_paths.append(common_templates_path)
-                    return MultiPathLoader(all_paths)
+                all_paths = []
+                if os.path.exists(app_template_path):
+                    all_paths.append(app_template_path)
+
+                all_paths.append(common_templates_path)
+                return MultiPathLoader(all_paths)
+
+            RequestHandler.create_template_loader = create_template_loader
 
             class RequestHandlerApp(WebApplication):
                 def get_handler_class(self):
@@ -183,15 +195,26 @@ class AppServer(object):
         for locator, handler_ in urls.urlpatterns.items():
             url = "^/{}".format(locator)
 
-            class RequestHandler(web.RequestHandler):
-                handler = handler_
+            if isinstance(handler_, type):
+                RequestHandler = handler_
 
-                def get(self):
-                    return self.handler({})
+            else:
+                class RequestHandler(settings.WebRequestHandler):
+                    handler = handler_  # automagically passes 'self'
+                    context = {}
 
-                def create_template_loader(self, path):
-                    all_paths = [common_templates_path]
-                    return MultiPathLoader(all_paths)
+                    if getattr(handler_, "use_post", None):
+                        def post(self):
+                            return self.handler(self.context)
+                    else:
+                        def get(self):
+                            return self.handler(self.context)
+
+            def create_template_loader(self, path):
+                all_paths = [common_templates_path]
+                return MultiPathLoader(all_paths)
+
+            RequestHandler.create_template_loader = create_template_loader
 
             class RequestHandlerApp(WebApplication):
                 def get_handler_class(self):
@@ -200,6 +223,15 @@ class AppServer(object):
             app = RequestHandlerApp(self.ws, url)
             self.ws.registerApplication(app)
 
+    def register_common_servants(self):
+        try:
+            servants = importlib.import_module("servants")
+            servants.register_servants(self.wise_adapter)
+        except Exception as e:
+            logger.info(str(e))
+            logger.info("could not load common servants")
+            return
+
     def communicator(self):
         return self.ws
 
@@ -208,4 +240,3 @@ class AppServer(object):
 
     def stop(self):
         self.ws.shutdown()
-
