@@ -146,7 +146,7 @@ wise = {
 no_reconnect: false,
 
 _get_typecode: function(value) {
-    if (value === undefined || value === null)
+    if (value === undefined || value === null || value.wise_typecode === undefined)
 	return undefined;
 
     return value && value["wise_typecode"];
@@ -165,9 +165,13 @@ Transceiver: Class.extend({
 	// FIXME: this attribute may be replaced with a promise that support several
 	// fulfill callbacks
 	this._waiting_callbacks = [promise];
-
 	this._is_ready = false;
-	this._socket_url = "ws://" + endpoint.host +
+
+	var proto = "ws";
+	if (this.use_secure_ws || location.protocol == "https:")
+	    proto = "wss";
+
+	this._socket_url = proto + "://" + endpoint.host +
 	    ":" +  endpoint.port + "/" + endpoint.ws_name;
 
 	log.debug("new WebSocket: " + this._socket_url);
@@ -1134,6 +1138,10 @@ WiseException: function(name, message) {
     this.message = message;
 },
 
+secure: function(state) {
+    this.use_secure_ws = state;
+},
+
 }; // wise namespace
 
 wise.WiseException.prototype = new Error();
